@@ -262,14 +262,14 @@ def cell_signal_handler(*args):
     app_object.current_cellid = args[2]
     # Update UI with current CellID
     app_object.update_name()
-
+    #print app_object.current_cellid , " in ",app_object.searchCellID
     # Does it match the preset CellID?
     if( app_object.searchCellID ):
         if( app_object.current_cellid in app_object.searchCellID ):
             if( app_object.enableAlarm ):
                 add_two_button_alarm()
             app_object.ui.pushButtonStart.setText("Arrived at ["+app_object.cellID_name+"]. Click again to set new destination.")
-        app_object.searchCellID = None
+            app_object.searchCellID = None
 
     if( app_object.enableGSMAlarm and (args[3] != 0 and args[4] != 0) ):
         app_object.enableGSMAlarm = False
@@ -278,9 +278,6 @@ def cell_signal_handler(*args):
 
 if __name__ == '__main__':
     app = QtGui.QApplication(sys.argv)
-
-    #workaround for bug #6642
-    import gobject
     app_object = MyForm()
     app_object.show()
     sys.exit(app.exec_())
